@@ -98,7 +98,7 @@ def _check_name_encoding(name):
     try:
         name.decode("utf-8")
     except UnicodeDecodeError as e:
-        raise InvalidRecordError(str(e))
+        raise InvalidRecordError(str(e)) from e
 
 
 class ContainerSerialiser:
@@ -242,8 +242,8 @@ class ReadVFile:
         result = self._string.read(length)
         if len(result) < length:
             raise errors.BzrError(
-                "wanted %d bytes but next "
-                "hunk only contains %d: %r..." % (length, len(result), result[:20])
+                f"wanted {length} bytes but next "
+                f"hunk only contains {len(result)}: {result[:20]!r}..."
             )
         return result
 
@@ -253,7 +253,7 @@ class ReadVFile:
         result = self._string.readline()
         if self._string.tell() == self._string_length and result[-1:] != b"\n":
             raise errors.BzrError(
-                "short readline in the readvfile hunk: %r" % (result,)
+                "short readline in the readvfile hunk: {!r}".format(result)
             )
         return result
 
@@ -408,8 +408,10 @@ class BytesRecordReader(BaseReader):
         length_line = self._read_line()
         try:
             length = int(length_line)
-        except ValueError:
-            raise InvalidRecordError("{!r} is not a valid length.".format(length_line))
+        except ValueError as e:
+            raise InvalidRecordError(
+                "{!r} is not a valid length.".format(length_line)
+            ) from e
 
         # Read the list of names.
         names = []
@@ -532,8 +534,10 @@ class ContainerPushParser:
         if line is not None:
             try:
                 self._current_record_length = int(line)
-            except ValueError:
-                raise InvalidRecordError("{!r} is not a valid length.".format(line))
+            except ValueError as e:
+                raise InvalidRecordError(
+                    "{!r} is not a valid length.".format(line)
+                ) from e
             self._state_handler = self._state_expecting_name
 
     def _state_expecting_name(self):
