@@ -19,7 +19,7 @@ import os
 
 
 def get_module(target):
-    mod_name = "breezy.doc_generate.autodoc_%s" % (target)
+    mod_name = "breezy.doc_generate.autodoc_{}".format(target)
     mod = __import__(mod_name)
     components = mod_name.split(".")
     for comp in components[1:]:
