@@ -72,7 +72,7 @@ class TestSend(tests.TestCaseWithTransport, TestSendMixin):
         self.assertEqual(fmt_string, md.get_raw_bundle().splitlines()[0])
 
     def test_uses_parent(self):
-        """Parent location is used as a basis by default"""
+        """Parent location is used as a basis by default."""
         errmsg = self.run_send([], rc=3, wd="grandparent")[1]
         self.assertContainsRe(errmsg, "No submit branch known or specified")
         stdout, stderr = self.run_send([])
@@ -80,7 +80,7 @@ class TestSend(tests.TestCaseWithTransport, TestSendMixin):
         self.assertBundleContains([b"rev3"], [])
 
     def test_bundle(self):
-        """Bundle works like send, except -o is not required"""
+        """Bundle works like send, except -o is not required."""
         errmsg = self.run_send([], cmd=["bundle"], rc=3, wd="grandparent")[1]
         self.assertContainsRe(errmsg, "No submit branch known or specified")
         stdout, stderr = self.run_send([], cmd=["bundle"])
@@ -88,7 +88,7 @@ class TestSend(tests.TestCaseWithTransport, TestSendMixin):
         self.assertBundleContains([b"rev3"], [], cmd=["bundle"])
 
     def test_uses_submit(self):
-        """Submit location can be used and set"""
+        """Submit location can be used and set."""
         self.assertBundleContains([b"rev3"], [])
         self.assertBundleContains([b"rev3", b"rev2"], ["../grandparent"])
         # submit location should be auto-remembered
@@ -127,7 +127,7 @@ class TestSend(tests.TestCaseWithTransport, TestSendMixin):
         self.run_send(["--from", "foo", "../bar"], wd="foo")
 
     def test_content_options(self):
-        """--no-patch and --no-bundle should work and be independant"""
+        """--no-patch and --no-bundle should work and be independant."""
         md = self.get_MD([])
         self.assertIsNot(None, md.bundle)
         self.assertIsNot(None, md.patch)
@@ -264,7 +264,7 @@ class TestSend(tests.TestCaseWithTransport, TestSendMixin):
         location = self.get_url("absentdir/")
         out, err = self.run_bzr(["send", "--from", location], retcode=3)
         self.assertEqual(out, "")
-        self.assertEqual(err, 'brz: ERROR: Not a branch: "%s".\n' % location)
+        self.assertEqual(err, 'brz: ERROR: Not a branch: "{}".\n'.format(location))
 
 
 class TestSendStrictMixin(TestSendMixin):
@@ -285,7 +285,7 @@ class TestSendStrictMixin(TestSendMixin):
     _default_wd = "local"
     _default_sent_revs = None
     _default_errors = [
-        'Working tree ".*/local/" has uncommitted ' "changes \\(See brz status\\)\\.",
+        'Working tree ".*/local/" has uncommitted changes \\(See brz status\\)\\.',
     ]
     _default_additional_error = "Use --no-strict to force the send.\n"
     _default_additional_warning = "Uncommitted changes will not be sent."
@@ -307,9 +307,9 @@ class TestSendStrictMixin(TestSendMixin):
             revs = self._default_sent_revs or [self.local]
         out, err = self.run_send(args, err_re=err_re)
         if len(revs) == 1:
-            bundling_revs = "Bundling %d revision.\n" % len(revs)
+            bundling_revs = f"Bundling {len(revs)} revision.\n"
         else:
-            bundling_revs = "Bundling %d revisions.\n" % len(revs)
+            bundling_revs = f"Bundling {len(revs)} revisions.\n"
         if with_warning:
             self.assertContainsRe(err, self._default_additional_warning)
             self.assertEndsWith(err, bundling_revs)
@@ -353,9 +353,9 @@ class TestSendStrictWithChanges(tests.TestCaseWithTransport, TestSendStrictMixin
     # but since the functions are reimplemented here, the definitions are left
     # here too.
     scenarios = [
-        ("uncommitted", dict(_changes_type="_uncommitted_changes")),
-        ("pending_merges", dict(_changes_type="_pending_merges")),
-        ("out-of-sync-trees", dict(_changes_type="_out_of_sync_trees")),
+        ("uncommitted", {"_changes_type": "_uncommitted_changes"}),
+        ("pending_merges", {"_changes_type": "_pending_merges"}),
+        ("out-of-sync-trees", {"_changes_type": "_out_of_sync_trees"}),
     ]
 
     _changes_type = None  # Set by load_tests
@@ -393,7 +393,7 @@ class TestSendStrictWithChanges(tests.TestCaseWithTransport, TestSendStrictMixin
         # Exercise commands from the checkout directory
         self._default_wd = "checkout"
         self._default_errors = [
-            "Working tree is out of date, please run" " 'brz update'\\.",
+            "Working tree is out of date, please run 'brz update'\\.",
         ]
         self._default_sent_revs = [b"modified-in-local", self.local]
 
