@@ -16,7 +16,7 @@
 
 """Tests for Tree.revision_tree."""
 
-from breezy import errors, tests
+from breezy import errors
 from breezy.tests import per_tree
 
 
