@@ -14,6 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+__docformat__ = "google"
+
 """Abstraction for interacting with the user.
 
 Applications can choose different types of UI, and they deal with displaying
@@ -23,17 +25,21 @@ Several levels are supported, and you can also register new factories such as
 for a GUI.
 
 breezy.ui.UIFactory
+
     Semi-abstract base class
 
 breezy.ui.SilentUIFactory
+
     Produces no output and cannot take any input; useful for programs using
     breezy in batch mode or for programs such as loggerhead.
 
 breezy.ui.CannedInputUIFactory
+
     For use in testing; the input values to be returned are provided
     at construction.
 
 breezy.ui.text.TextUIFactory
+
     Standard text command-line interface, with stdin, stdout, stderr.
     May make more or less advanced use of them, eg in drawing progress bars,
     depending on the detected capabilities of the terminal.
@@ -43,22 +49,18 @@ breezy.ui.text.TextUIFactory
 
 import warnings
 
-from ..lazy_import import lazy_import
-lazy_import(globals(), """
-from breezy import (
-    config,
-    osutils,
-    progress,
-    )
-""")
-
-
-_valid_boolean_strings = dict(yes=True, no=False,
-                              y=True, n=False,
-                              on=True, off=False,
-                              true=True, false=False)
-_valid_boolean_strings['1'] = True
-_valid_boolean_strings['0'] = False
+_valid_boolean_strings = {
+    "yes": True,
+    "no": False,
+    "y": True,
+    "n": False,
+    "on": True,
+    "off": False,
+    "true": True,
+    "false": False,
+}
+_valid_boolean_strings["1"] = True
+_valid_boolean_strings["0"] = False
 
 
 def bool_from_string(s, accepted_values=None):
@@ -69,14 +71,16 @@ def bool_from_string(s, accepted_values=None):
     'off'. Alternative values can be provided with the 'accepted_values'
     parameter.
 
-    :param s: A string that should be interpreted as a boolean. It should be of
-        type string or unicode.
+    Args:
+      s: A string that should be interpreted as a boolean. It should be of
+         type string or unicode.
 
-    :param accepted_values: An optional dict with accepted strings as keys and
-        True/False as values. The strings will be tested against a lowered
-        version of 's'.
+      accepted_values: An optional dict with accepted strings as keys and
+         True/False as values. The strings will be tested against a lowered
+         version of 's'.
 
-    :return: True or False for accepted strings, None otherwise.
+    Returns:
+      True or False for accepted strings, None otherwise.
     """
     if accepted_values is None:
         accepted_values = _valid_boolean_strings
@@ -89,17 +93,18 @@ def bool_from_string(s, accepted_values=None):
     return val
 
 
-class ConfirmationUserInterfacePolicy(object):
+class ConfirmationUserInterfacePolicy:
     """Wrapper for a UIFactory that allows or denies all confirmed actions."""
 
     def __init__(self, wrapped_ui, default_answer, specific_answers):
         """Generate a proxy UI that does no confirmations.
 
-        :param wrapped_ui: Underlying UIFactory.
-        :param default_answer: Bool for whether requests for
+        Args:
+          wrapped_ui: Underlying UIFactory.
+          default_answer: Bool for whether requests for
             confirmation from the user should be noninteractively accepted or
             denied.
-        :param specific_answers: Map from confirmation_id to bool answer.
+          specific_answers: Map from confirmation_id to bool answer.
         """
         self.wrapped_ui = wrapped_ui
         self.default_answer = default_answer
@@ -109,11 +114,12 @@ class ConfirmationUserInterfacePolicy(object):
         return getattr(self.wrapped_ui, name)
 
     def __repr__(self):
-        return '%s(%r, %r, %r)' % (
+        return "{}({!r}, {!r}, {!r})".format(
             self.__class__.__name__,
             self.wrapped_ui,
             self.default_answer,
-            self.specific_answers)
+            self.specific_answers,
+        )
 
     def confirm_action(self, prompt, confirmation_id, prompt_kwargs):
         if confirmation_id in self.specific_answers:
@@ -122,10 +128,11 @@ class ConfirmationUserInterfacePolicy(object):
             return self.default_answer
         else:
             return self.wrapped_ui.confirm_action(
-                prompt, confirmation_id, prompt_kwargs)
+                prompt, confirmation_id, prompt_kwargs
+            )
 
 
-class UIFactory(object):
+class UIFactory:
     """UI abstraction.
 
     This tells the library how to display things to the user.  Through this
@@ -134,38 +141,44 @@ class UIFactory(object):
     UI Factories are also context managers, for some syntactic sugar some users
     need.
 
-    :ivar suppressed_warnings: Identifiers for user warnings that should
-        no be emitted.
+    Attributes:
+      suppressed_warnings: Identifiers for user warnings that should
+                           no be emitted.
     """
 
-    _user_warning_templates = dict(
-        cross_format_fetch=("Doing on-the-fly conversion from "
-                            "%(from_format)s to %(to_format)s.\n"
-                            "This may take some time. Upgrade the repositories to the "
-                            "same format for better performance."
-                            ),
-        experimental_format_fetch=("Fetching into experimental format "
-                                   "%(to_format)s.\n"
-                                   "This format may be unreliable or change in the future "
-                                   "without an upgrade path.\n"),
-        deprecated_command=(
+    _user_warning_templates = {
+        "cross_format_fetch": (
+            "Doing on-the-fly conversion from "
+            "%(from_format)s to %(to_format)s.\n"
+            "This may take some time. Upgrade the repositories to the "
+            "same format for better performance."
+        ),
+        "experimental_format_fetch": (
+            "Fetching into experimental format "
+            "%(to_format)s.\n"
+            "This format may be unreliable or change in the future "
+            "without an upgrade path.\n"
+        ),
+        "deprecated_command": (
             "The command 'brz %(deprecated_name)s' "
             "has been deprecated in brz %(deprecated_in_version)s. "
-            "Please use 'brz %(recommended_name)s' instead."),
-        deprecated_command_option=(
+            "Please use 'brz %(recommended_name)s' instead."
+        ),
+        "deprecated_command_option": (
             "The option '%(deprecated_name)s' to 'brz %(command)s' "
             "has been deprecated in brz %(deprecated_in_version)s. "
-            "Please use '%(recommended_name)s' instead."),
-        recommend_upgrade=("%(current_format_name)s is deprecated "
-                           "and a better format is available.\n"
-                           "It is recommended that you upgrade by "
-                           "running the command\n"
-                           "  brz upgrade %(basedir)s"),
-        locks_steal_dead=(
-            u"Stole dead lock %(lock_url)s %(other_holder_info)s."),
-        not_checking_ssl_cert=(
-            u"Not checking SSL certificate for %(host)s."),
-        )
+            "Please use '%(recommended_name)s' instead."
+        ),
+        "recommend_upgrade": (
+            "%(current_format_name)s is deprecated "
+            "and a better format is available.\n"
+            "It is recommended that you upgrade by "
+            "running the command\n"
+            "  brz upgrade %(basedir)s"
+        ),
+        "locks_steal_dead": ("Stole dead lock %(lock_url)s %(other_holder_info)s."),
+        "not_checking_ssl_cert": ("Not checking SSL certificate for %(host)s."),
+    }
 
     def __init__(self):
         self._task_stack = []
@@ -208,22 +221,24 @@ class UIFactory(object):
         always be confirmed or always denied, and for UIs to specialize the
         display of particular confirmations.
 
-        :param prompt: Suggested text to display to the user.
-        :param prompt_kwargs: A dictionary of arguments that can be
-            string-interpolated into the prompt.
-        :param confirmation_id: Unique string identifier for the confirmation.
+        Args:
+          prompt: Suggested text to display to the user.
+          prompt_kwargs: A dictionary of arguments that can be
+              string-interpolated into the prompt.
+          confirmation_id: Unique string identifier for the confirmation.
         """
         return self.get_boolean(prompt % prompt_kwargs)
 
-    def get_password(self, prompt=u'', **kwargs):
+    def get_password(self, prompt="", **kwargs):
         """Prompt the user for a password.
 
-        :param prompt: The prompt to present the user (must be unicode)
-        :param kwargs: Arguments which will be expanded into the prompt.
+        Args:
+          prompt: The prompt to present the user (must be unicode)
+          kwargs: Arguments which will be expanded into the prompt.
                        This lets front ends display different things if
                        they so choose.
 
-        :return: The password string, return None if the user canceled the
+        Returns: The password string, return None if the user canceled the
                  request. Note that we do not touch the encoding, users may
                  have whatever they see fit and the password should be
                  transported as is.
@@ -233,7 +248,7 @@ class UIFactory(object):
     def is_quiet(self):
         return self._quiet
 
-    def make_output_stream(self, encoding=None, encoding_type='replace'):
+    def make_output_stream(self, encoding=None, encoding_type="replace"):
         """Get a stream for sending out bulk text data.
 
         This is used for commands that produce bulk text, such as log or diff
@@ -244,20 +259,22 @@ class UIFactory(object):
 
         The caller may flush but should not close the returned stream.
 
-        :param encoding: Unicode encoding for output; if not specified
+        Args:
+          encoding: Unicode encoding for output; if not specified
             uses the configured 'output_encoding' if any; otherwise the
             terminal encoding.
             (See get_terminal_encoding.)
 
-        :param encoding_type: How to handle encoding errors:
+          encoding_type: How to handle encoding errors:
             replace/strict/escape/exact.  Default is replace.
         """
         out_stream = self._make_output_stream_explicit(encoding, encoding_type)
         return out_stream
 
     def _make_output_stream_explicit(self, encoding, encoding_type):
-        raise NotImplementedError("%s doesn't support make_output_stream"
-                                  % (self.__class__.__name__))
+        raise NotImplementedError(
+            "{} doesn't support make_output_stream".format(self.__class__.__name__)
+        )
 
     def nested_progress_bar(self):
         """Return a nested progress bar.
@@ -265,28 +282,33 @@ class UIFactory(object):
         When the bar has been finished with, it should be released by calling
         bar.finished().
         """
+        from ..progress import ProgressTask
+
         if self._task_stack:
-            t = progress.ProgressTask(self._task_stack[-1], self)
+            t = ProgressTask(self._task_stack[-1], self)
         else:
-            t = progress.ProgressTask(None, self)
+            t = ProgressTask(None, self)
         self._task_stack.append(t)
         return t
 
     def _progress_finished(self, task):
-        """Called by the ProgressTask when it finishes"""
+        """Called by the ProgressTask when it finishes."""
         if not self._task_stack:
-            warnings.warn("%r finished but nothing is active"
-                          % (task,))
+            warnings.warn(
+                "{!r} finished but nothing is active".format(task), stacklevel=2
+            )
         if task in self._task_stack:
             self._task_stack.remove(task)
         else:
-            warnings.warn("%r is not in active stack %r"
-                          % (task, self._task_stack))
+            warnings.warn(
+                "{!r} is not in active stack {!r}".format(task, self._task_stack),
+                stacklevel=2,
+            )
         if not self._task_stack:
             self._progress_all_finished()
 
     def _progress_all_finished(self):
-        """Called when the top-level progress task finished"""
+        """Called when the top-level progress task finished."""
         pass
 
     def _progress_updated(self, task):
@@ -308,55 +330,64 @@ class UIFactory(object):
         try:
             template = self._user_warning_templates[warning_id]
         except KeyError:
-            fail = "brz warning: %r, %r" % (warning_id, message_args)
-            warnings.warn("no template for warning: "
-                          + fail)   # so tests will fail etc
+            fail = "brz warning: {!r}, {!r}".format(warning_id, message_args)
+            warnings.warn(
+                "no template for warning: " + fail, stacklevel=2
+            )  # so tests will fail etc
             return str(fail)
         try:
             return str(template) % message_args
         except ValueError as e:
-            fail = "brz unprintable warning: %r, %r, %s" % (
-                warning_id, message_args, e)
-            warnings.warn(fail)   # so tests will fail etc
+            fail = "brz unprintable warning: {!r}, {!r}, {}".format(
+                warning_id, message_args, e
+            )
+            warnings.warn(fail, stacklevel=2)  # so tests will fail etc
             return str(fail)
 
     def choose(self, msg, choices, default=None):
-        """Prompt the user for a list of alternatives.
+        r"""Prompt the user for a list of alternatives.
 
-        :param msg: message to be shown as part of the prompt.
+        Args:
+          msg: message to be shown as part of the prompt.
 
-        :param choices: list of choices, with the individual choices separated
+          choices: list of choices, with the individual choices separated
             by '\n', e.g.: choose("Save changes?", "&Yes\n&No\n&Cancel"). The
             letter after the '&' is the shortcut key for that choice. Thus you
             can type 'c' to select "Cancel".  Shorcuts are case insensitive.
             The shortcut does not need to be the first letter. If a shorcut key
             is not provided, the first letter for the choice will be used.
 
-        :param default: default choice (index), returned for example when enter
+          default: default choice (index), returned for example when enter
             is pressed for the console version.
 
-        :return: the index fo the user choice (so '0', '1' or '2' for
-            respectively yes/no/cancel in the previous example).
+        Returns:
+          the index fo the user choice (so '0', '1' or '2' for respectively
+          yes/no/cancel in the previous example).
         """
         raise NotImplementedError(self.choose)
 
     def get_boolean(self, prompt):
-        """Get a boolean question answered from the user.
+        r"""Get a boolean question answered from the user.
 
-        :param prompt: a message to prompt the user with. Should be a single
+        Args:
+          prompt: a message to prompt the user with. Should be a single
             line without terminating \\n.
-        :return: True or False for y/yes or n/no.
+
+        Returns:
+          True or False for y/yes or n/no.
         """
-        choice = self.choose(prompt + '?', '&yes\n&no', default=None)
-        return 0 == choice
+        choice = self.choose(prompt + "?", "&yes\n&no", default=None)
+        return choice == 0
 
     def get_integer(self, prompt):
-        """Get an integer from the user.
+        r"""Get an integer from the user.
 
-        :param prompt: a message to prompt the user with. Could be a multi-line
+        Args:
+          prompt: a message to prompt the user with. Could be a multi-line
             prompt but without a terminating \\n.
 
-        :return: A signed integer.
+        Returns:
+          A signed integer.
         """
         raise NotImplementedError(self.get_integer)
 
@@ -371,11 +402,15 @@ class UIFactory(object):
     def recommend_upgrade(self, current_format_name, basedir):
         """Recommend the user upgrade a control directory.
 
-        :param current_format_name: Description of the current format
-        :param basedir: Location of the control dir
+        Args:
+          current_format_name: Description of the current format
+          basedir: Location of the control dir
         """
-        self.show_user_warning('recommend_upgrade',
-                               current_format_name=current_format_name, basedir=basedir)
+        self.show_user_warning(
+            "recommend_upgrade",
+            current_format_name=current_format_name,
+            basedir=basedir,
+        )
 
     def report_transport_activity(self, transport, byte_count, direction):
         """Called by transports as they do IO.
@@ -391,9 +426,12 @@ class UIFactory(object):
         Implementations are allowed to do nothing, but it is useful if they can
         write a line to the log file.
 
-        :param display: If False, only log to disk, if True also try to display
+        Args:
+          display: If False, only log to disk, if True also try to display
             a message to the user.
-        :return: None
+
+        Returns:
+          None
         """
         # Default implementation just does nothing
         pass
@@ -410,9 +448,10 @@ class UIFactory(object):
         nothing.  format_user_warning maps it to a string, though other
         presentations can be used for particular UIs.
 
-        :param warning_id: An identifier like 'cross_format_fetch' used to
+        Args:
+          warning_id: An identifier like 'cross_format_fetch' used to
             check if the message is suppressed and to look up the string.
-        :param message_args: Arguments to be interpolated into the message.
+          message_args: Arguments to be interpolated into the message.
         """
         pass
 
@@ -440,7 +479,7 @@ class NoninteractiveUIFactory(UIFactory):
         return True
 
     def __repr__(self):
-        return '%s()' % (self.__class__.__name__, )
+        return "{}()".format(self.__class__.__name__)
 
 
 class SilentUIFactory(NoninteractiveUIFactory):
@@ -482,7 +521,7 @@ class CannedInputUIFactory(SilentUIFactory):
         self.responses = responses
 
     def __repr__(self):
-        return "%s(%r)" % (self.__class__.__name__, self.responses)
+        return "{}({!r})".format(self.__class__.__name__, self.responses)
 
     def confirm_action(self, prompt, confirmation_id, args):
         return self.get_boolean(prompt % args)
@@ -493,7 +532,7 @@ class CannedInputUIFactory(SilentUIFactory):
     def get_integer(self, prompt):
         return self.responses.pop(0)
 
-    def get_password(self, prompt=u'', **kwargs):
+    def get_password(self, prompt="", **kwargs):
         return self.responses.pop(0)
 
     def get_username(self, prompt, **kwargs):
@@ -501,8 +540,9 @@ class CannedInputUIFactory(SilentUIFactory):
 
     def assert_all_input_consumed(self):
         if self.responses:
-            raise AssertionError("expected all input in %r to be consumed"
-                                 % (self,))
+            raise AssertionError(
+                "expected all input in {!r} to be consumed".format(self)
+            )
 
 
 ui_factory = SilentUIFactory()
@@ -511,15 +551,15 @@ ui_factory = SilentUIFactory()
 
 
 def make_ui_for_terminal(stdin, stdout, stderr):
-    """Construct and return a suitable UIFactory for a text mode program.
-    """
+    """Construct and return a suitable UIFactory for a text mode program."""
     # this is now always TextUIFactory, which in turn decides whether it
     # should display progress bars etc
     from .text import TextUIFactory
+
     return TextUIFactory(stdin, stdout, stderr)
 
 
-class NullProgressView(object):
+class NullProgressView:
     """Soak up and ignore progress information."""
 
     def clear(self):
@@ -535,7 +575,7 @@ class NullProgressView(object):
         pass
 
 
-class NullOutputStream(object):
+class NullOutputStream:
     """Acts like a file, but discard all output."""
 
     def __init__(self, encoding):
